@@ -5,6 +5,7 @@
 #
 
 from fabric.api import cd, local, lcd, puts, run, sudo, put
+from fabric.colors import green, red, magenta
 from unipath import Path
 from .api import virtualenv
 from .errors import GitError
@@ -12,6 +13,7 @@ from .decorators import easyfabtask
 from .items import BaseItem
 from .utils import process_directory, get_relative_path, get_project_name
 
+import inspect
 
 class BaseDeployment(object):
     """ BaseDeployment class
@@ -77,7 +79,7 @@ class BaseDeployment(object):
 
     @easyfabtask
     def make_package(self, force_make_package=True, **options):
-        """ Makes package
+        """ Creates package to deployment/.packages/
         """
         def copy_files(context):
             # copy files from deployments
@@ -157,7 +159,7 @@ class BaseDeployment(object):
 
     @easyfabtask
     def manage(self, arg):
-        """ Manageee
+        """ Runs manage.py command on remote hosts
         """
         full_manage_dir = Path(self.target_dir, Path(self.manage_dir))
         with virtualenv(str(self.virtualenv_dir), full_manage_dir):
@@ -173,6 +175,35 @@ class BaseDeployment(object):
         with virtualenv(str(self.virtualenv_dir), '/tmp'):
             run('pip install -r requirements.txt')
 
+    @easyfabtask
+    def list_commands(self):
+        """ Returns list of available easyfab commands for current deployment
+        """
+        for i in dir(self):
+            attr = getattr(self, i)
+            if not callable(attr):
+                continue
+            if getattr(attr, '__easyfabtask', None):
+                if attr.__doc__:
+                    doc = attr.__doc__.strip()
+                else:
+                    doc = None
+                result = {
+                    'name': attr.__name__,
+                    'doc': doc,
+                    'args': None
+                }
+
+                argspec = inspect.getargspec(attr)
+                if argspec.args:
+                    result['args'] = argspec.args
+
+                print red(result['name'])
+                if result['doc']:
+                    print "\t" + result['doc']
+                if result['args']:
+                    print magenta('args:' + str(result['args']))
+
     def pre_deploy(self):
         """ Callback called before deploy, best place to run compilemessages,
             collectstatic and other commands
@@ -184,7 +215,7 @@ class BaseDeployment(object):
         """
 
     def log(self, message, level='INFO'):
-        puts(": ".join((level, message)))
+        puts(green('easyfab:') + (" ".join((level, message))))
 
     def get_context_data(self, **kwargs):
         """ returns data to be added to deployment, after make package
